@@ -112,9 +112,8 @@ replyr_mapRestrictCols <- function(x, nmap,
   if(length(unique(names(nmap)))!=length(nmap)) {
     stop("replyr::replyr_mapRestrictCols duplicate destination columns (nmap keys) in replyr_mapRestrictCols")
   }
-  if(length(setdiff(as.character(nmap), colnames(x)))>0) {
-    stop("replyr::replyr_mapRestrictCols all source columns (nmap values) must be column names of x")
-  }
+  # restrict down to names in x
+  nmap <- nmap[as.character(nmap) %in% colnames(x)]
   if(!restrict) {
     dupMapping <- base::intersect(names(nmap), # destinations
                               setdiff(colnames(x), as.character(nmap)) # columns we are leaving in place
@@ -158,7 +157,7 @@ replyr_mapRestrictCols <- function(x, nmap,
   }
   if(restrict) {
     # limit down to only names we are mapping
-    x %>% dplyr::select(dplyr::one_of(as.character(nmap))) -> x
+    x <- dplyr::select(x, dplyr::one_of(as.character(nmap)))
   }
   # re-map names, re-factor mapping to two maps to avoid
   # name-aliasing issues
@@ -226,6 +225,9 @@ replyr_apply_f_mapped <- function(d,
                                   restrictMapIn = FALSE,
                                   rmap = replyr::replyr_reverseMap(nmap),
                                   restrictMapOut = FALSE) {
+  if(length(list(...))>0) {
+    stop("replyr_apply_f_mapped: unexpected arguments")
+  }
   dMapped <- replyr_mapRestrictCols(d, nmap,
                                     restrict = restrictMapIn)
   dF <- f(dMapped)
